@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use utf8; # filenames can be in utf8
 
@@ -46,7 +46,6 @@ sub	new {
 		verbosity
 		output-filename
 		frame-duration
-		ffmpeg-executable
 	/){
 		if( exists($params->{$ak}) && defined($params->{$ak}) ){
 			$self->{$ak} = $params->{$ak}
@@ -131,8 +130,11 @@ sub	_build_ffmpeg_cmdline {
 	}
 	close $fh;
 
+	my $execu = $self->ffmpeg_executable();
+	if( ! defined $execu ){ print STDERR "$whoami() (via $parent), line ".__LINE__." : error, the path to the ffmpeg executable is undefined. That means that the external, 3rd-party dependency 'ffmpeg' was not located during installation. First you need to install ffmpeg. Then re-install current module. Note that if ffmpeg is installed in a non-standard location you need to specify that location (i.e. the full-path to the ffmpeg executable) at installation of this module by setting the environment variable 'AUTOMATE_ANIMATE_FFMPEG_PATH'. See the documentation (https://metacpan.org/pod/Automate::Animate::FFmpeg#INSTALLATION) for further details.\n"; return undef }
+
 	my @cmdline = (
-		$self->ffmpeg_executable(),
+		$execu,
 		# the extra params to FFmpeg is just a command-line args style
 		@{ $self->ffmpeg_extra_params() },
 		# and the concats etc.
@@ -184,7 +186,7 @@ sub	_cmdline2argsarray {
 	} elsif( ref($m) eq 'HASH' ){
 		return [ %$m ];
 	}
-	print STDERR "_cmdline2argsarray() : an ARRAYref/HASHref/String-scalar containing command-line arguments was expected, not ".ref($m)."\n";
+	print STDERR "_cmdline2argsarray() : error, an ARRAYref/HASHref/String-scalar containing command-line arguments was expected, not ".ref($m)."\n";
 	return undef
 }
 sub	ffmpeg_extra_params {
@@ -299,11 +301,11 @@ sub	input_images {
 
 =head1 NAME
 
-Automate::Animate::FFmpeg - Create animation from a sequence of images using ffmpeg
+Automate::Animate::FFmpeg - Create animation from a sequence of images using FFmpeg
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 
 =head1 SYNOPSIS
@@ -312,6 +314,8 @@ This module creates an animation from a sequence of input
 images using L<FFmpeg|https://ffmpeg.org>.
 An excellent, open source program.
 
+FFmpeg binaries must already be installed in your system.
+
     use Automate::Animate::FFmpeg;
     my $aaFFobj = Automate::Animate::FFmpeg->new({
       # specify input images in any of these 3 ways:
@@ -347,6 +351,50 @@ An excellent, open source program.
       unless $aaFF->make_animation()
     ;
 
+=head1 INSTALLATION
+
+During "making the makefile" (C<perl Makefile.PL>),
+there will be a check to locate the binary C<ffmpeg>
+in your system. At first it checks if the environment
+variable C<AUTOMATE_ANIMATE_FFMPEG_PATH> is set, for example,
+in *nix, you can set this variable and do the installation like this:
+
+    AUTOMATE_ANIMATE_FFMPEG_PATH=/abc/xyz/ffmpeg perl Makefile.PL
+
+Or, if you do not have direct control to the installation process
+(e.g. via cpan/cpanm/package-manager) do it like this:
+
+    export AUTOMATE_ANIMATE_FFMPEG_PATH=/abc/xyz/ffmpeg
+    cpan -i Automate::Animate::FFmpeg
+
+Or, like this:
+
+    # this opens a shell after fetching the module tarball and unpacking it
+    cpanm --look Automate::Animate::FFmpeg
+    export AUTOMATE_ANIMATE_FFMPEG_PATH=/abc/xyz/ffmpeg
+    perl Makefile.PL
+    ...
+
+If the environment variable C<AUTOMATE_ANIMATE_FFMPEG_PATH> was not set,
+the installer will search in the "usual" locations for the ffmpeg
+binaries. This is done by L<File::Which>'s C<which()>.
+
+If nothing was found, then it is assumed that C<ffmpeg> is not installed.
+B<But>, the installation will proceed with a warning. Tests
+will be run, but they too will succeed (with a warning) on the
+absence of an C<ffmpeg> executable.
+The location
+to the C<ffmpeg> binaries will be left undefined in the module's
+installed scripts and the module will be totally unusable.
+This choice was made in order not to fail the tests when
+C<ffmpeg> is missing from test machines.
+
+Installation of C<ffmpeg> binaries is straightforward from
+their L<website|https://ffmpeg.org//download.html> for Linux, OSX
+and windows, if you are still using it. Many Linux distributions
+offer C<ffmpeg> via their package managers. That, or
+download a static build from said website.
+
 =head1 METHODS
 
 =head2 C<new>
@@ -536,6 +584,32 @@ in the produced animation.
 A script for making animations from input images using C<ffmpeg>
 is provided: C<automate-animate-ffmpeg.pl>.
 
+It accepts the following options:
+
+    --input-image I [--input-image I2 ...] : specify the full path of an 
+    image to be added to the animation. Multiple images are expected.
+
+      OR
+
+    --input-images-from-file F [--input-images-from-file F2 ...] : 
+    specify a file which contains a list of input images to be animated, 
+    each on its own line. Multiple images are expected.
+
+      OR
+
+    --input-pattern P D : specify a pattern AND a search dir to select 
+    the files from disk. This pattern must be accepted by 
+    File::Find::Rule::name().
+
+    --output-filename O : the filename of the output animation.
+
+    [--frame-duration SECONDS : specify the duration of each frame=input 
+    image in (fractional) seconds.]
+
+    [--verbosity N : specify verbosity. Zero being the mute. Default is 
+    0.]
+
+
 
 =head1 AUTHOR
 
